# Pickelhaube

[![PyPI - Version](https://img.shields.io/pypi/v/pickelhaube.svg)](https://pypi.org/project/pickelhaube)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pickelhaube.svg)](https://pypi.org/project/pickelhaube)

-----

Secure Pickling.

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install pickelhaube
```

## License

`pickelhaube` is distributed under the terms of the [AGPLv3 or
later](https://spdx.org/licenses/AGPL-3.0-or-later.html) license, see
[LICENSE](LICENSE).
